@@ -10,7 +10,7 @@
 //! # Video Encoding/Decoding
 use crate::{mod_prelude::*, core, sys, types};
 pub mod prelude {
-	pub use { super::EncoderParamsTrait, super::EncoderCallBack, super::VideoWriter, super::VideoReader, super::RawVideoSource };
+	pub use { super::EncoderParamsTraitConst, super::EncoderParamsTrait, super::EncoderCallBackConst, super::EncoderCallBack, super::VideoWriterConst, super::VideoWriter, super::VideoReaderConst, super::VideoReader, super::RawVideoSourceConst, super::RawVideoSource };
 }
 
 pub const AV1: i32 = 11;
@@ -127,7 +127,7 @@ opencv_type_enum! { crate::cudacodec::SurfaceFormat }
 /// ## Overloaded parameters
 /// 
 /// * source: RAW video source implemented by user.
-pub fn create_video_reader_1(source: &core::Ptr::<dyn crate::cudacodec::RawVideoSource>) -> Result<core::Ptr::<dyn crate::cudacodec::VideoReader>> {
+pub fn create_video_reader_1(source: &core::Ptr<dyn crate::cudacodec::RawVideoSource>) -> Result<core::Ptr<dyn crate::cudacodec::VideoReader>> {
 	unsafe { sys::cv_cudacodec_createVideoReader_const_Ptr_RawVideoSource_R(source.as_raw_PtrOfRawVideoSource()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudacodec::VideoReader>::opencv_from_extern(r) } )
 }
 
@@ -137,7 +137,7 @@ pub fn create_video_reader_1(source: &core::Ptr::<dyn crate::cudacodec::RawVideo
 /// * filename: Name of the input video file.
 /// 
 /// FFMPEG is used to read videos. User can implement own demultiplexing with cudacodec::RawVideoSource
-pub fn create_video_reader(filename: &str) -> Result<core::Ptr::<dyn crate::cudacodec::VideoReader>> {
+pub fn create_video_reader(filename: &str) -> Result<core::Ptr<dyn crate::cudacodec::VideoReader>> {
 	extern_container_arg!(filename);
 	unsafe { sys::cv_cudacodec_createVideoReader_const_StringR(filename.opencv_as_extern()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudacodec::VideoReader>::opencv_from_extern(r) } )
 }
@@ -167,7 +167,7 @@ pub fn create_video_reader(filename: &str) -> Result<core::Ptr::<dyn crate::cuda
 /// 
 /// ## C++ default parameters
 /// * format: SF_BGR
-pub fn create_video_writer_2(encoder_callback: &core::Ptr::<dyn crate::cudacodec::EncoderCallBack>, frame_size: core::Size, fps: f64, format: crate::cudacodec::SurfaceFormat) -> Result<core::Ptr::<dyn crate::cudacodec::VideoWriter>> {
+pub fn create_video_writer_2(encoder_callback: &core::Ptr<dyn crate::cudacodec::EncoderCallBack>, frame_size: core::Size, fps: f64, format: crate::cudacodec::SurfaceFormat) -> Result<core::Ptr<dyn crate::cudacodec::VideoWriter>> {
 	unsafe { sys::cv_cudacodec_createVideoWriter_const_Ptr_EncoderCallBack_R_Size_double_SurfaceFormat(encoder_callback.as_raw_PtrOfEncoderCallBack(), frame_size.opencv_as_extern(), fps, format) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudacodec::VideoWriter>::opencv_from_extern(r) } )
 }
 
@@ -197,7 +197,7 @@ pub fn create_video_writer_2(encoder_callback: &core::Ptr::<dyn crate::cudacodec
 /// 
 /// ## C++ default parameters
 /// * format: SF_BGR
-pub fn create_video_writer_3(encoder_callback: &core::Ptr::<dyn crate::cudacodec::EncoderCallBack>, frame_size: core::Size, fps: f64, params: &crate::cudacodec::EncoderParams, format: crate::cudacodec::SurfaceFormat) -> Result<core::Ptr::<dyn crate::cudacodec::VideoWriter>> {
+pub fn create_video_writer_3(encoder_callback: &core::Ptr<dyn crate::cudacodec::EncoderCallBack>, frame_size: core::Size, fps: f64, params: &crate::cudacodec::EncoderParams, format: crate::cudacodec::SurfaceFormat) -> Result<core::Ptr<dyn crate::cudacodec::VideoWriter>> {
 	unsafe { sys::cv_cudacodec_createVideoWriter_const_Ptr_EncoderCallBack_R_Size_double_const_EncoderParamsR_SurfaceFormat(encoder_callback.as_raw_PtrOfEncoderCallBack(), frame_size.opencv_as_extern(), fps, params.as_raw_EncoderParams(), format) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudacodec::VideoWriter>::opencv_from_extern(r) } )
 }
 
@@ -216,7 +216,7 @@ pub fn create_video_writer_3(encoder_callback: &core::Ptr::<dyn crate::cudacodec
 /// 
 /// ## C++ default parameters
 /// * format: SF_BGR
-pub fn create_video_writer(file_name: &str, frame_size: core::Size, fps: f64, format: crate::cudacodec::SurfaceFormat) -> Result<core::Ptr::<dyn crate::cudacodec::VideoWriter>> {
+pub fn create_video_writer(file_name: &str, frame_size: core::Size, fps: f64, format: crate::cudacodec::SurfaceFormat) -> Result<core::Ptr<dyn crate::cudacodec::VideoWriter>> {
 	extern_container_arg!(file_name);
 	unsafe { sys::cv_cudacodec_createVideoWriter_const_StringR_Size_double_SurfaceFormat(file_name.opencv_as_extern(), frame_size.opencv_as_extern(), fps, format) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudacodec::VideoWriter>::opencv_from_extern(r) } )
 }
@@ -246,14 +246,18 @@ pub fn create_video_writer(file_name: &str, frame_size: core::Size, fps: f64, fo
 /// 
 /// ## C++ default parameters
 /// * format: SF_BGR
-pub fn create_video_writer_1(file_name: &str, frame_size: core::Size, fps: f64, params: &crate::cudacodec::EncoderParams, format: crate::cudacodec::SurfaceFormat) -> Result<core::Ptr::<dyn crate::cudacodec::VideoWriter>> {
+pub fn create_video_writer_1(file_name: &str, frame_size: core::Size, fps: f64, params: &crate::cudacodec::EncoderParams, format: crate::cudacodec::SurfaceFormat) -> Result<core::Ptr<dyn crate::cudacodec::VideoWriter>> {
 	extern_container_arg!(file_name);
 	unsafe { sys::cv_cudacodec_createVideoWriter_const_StringR_Size_double_const_EncoderParamsR_SurfaceFormat(file_name.opencv_as_extern(), frame_size.opencv_as_extern(), fps, params.as_raw_EncoderParams(), format) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudacodec::VideoWriter>::opencv_from_extern(r) } )
 }
 
 /// Callbacks for CUDA video encoder.
-pub trait EncoderCallBack {
+pub trait EncoderCallBackConst {
 	fn as_raw_EncoderCallBack(&self) -> *const c_void;
+
+}
+
+pub trait EncoderCallBack: crate::cudacodec::EncoderCallBackConst {
 	fn as_raw_mut_EncoderCallBack(&mut self) -> *mut c_void;
 
 	/// Callback function to signal the start of bitstream that is to be encoded.
@@ -289,195 +293,208 @@ pub trait EncoderCallBack {
 }
 
 /// Different parameters for CUDA video encoder.
-pub trait EncoderParamsTrait {
+pub trait EncoderParamsTraitConst {
 	fn as_raw_EncoderParams(&self) -> *const c_void;
-	fn as_raw_mut_EncoderParams(&mut self) -> *mut c_void;
 
 	/// NVVE_P_INTERVAL,
 	fn p_interval(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropP_Interval_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: p_interval")
 	}
 	
-	/// NVVE_P_INTERVAL,
-	fn set_p_interval(&mut self, val: i32) -> () {
-		unsafe { sys::cv_cudacodec_EncoderParams_setPropP_Interval_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_p_interval")
-	}
-	
 	/// NVVE_IDR_PERIOD,
 	fn idr_period(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropIDR_Period_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: idr_period")
 	}
 	
+	/// NVVE_DYNAMIC_GOP,
+	fn dynamic_gop(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropDynamicGOP_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: dynamic_gop")
+	}
+	
+	/// NVVE_RC_TYPE,
+	fn rc_type(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropRCType_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: rc_type")
+	}
+	
+	/// NVVE_AVG_BITRATE,
+	fn avg_bitrate(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropAvgBitrate_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: avg_bitrate")
+	}
+	
+	/// NVVE_PEAK_BITRATE,
+	fn peak_bitrate(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropPeakBitrate_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: peak_bitrate")
+	}
+	
+	/// NVVE_QP_LEVEL_INTRA,
+	fn qp_level_intra(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropQP_Level_Intra_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: qp_level_intra")
+	}
+	
+	/// NVVE_QP_LEVEL_INTER_P,
+	fn qp_level_inter_p(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropQP_Level_InterP_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: qp_level_inter_p")
+	}
+	
+	/// NVVE_QP_LEVEL_INTER_B,
+	fn qp_level_inter_b(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropQP_Level_InterB_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: qp_level_inter_b")
+	}
+	
+	/// NVVE_DEBLOCK_MODE,
+	fn deblock_mode(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropDeblockMode_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: deblock_mode")
+	}
+	
+	/// NVVE_PROFILE_LEVEL,
+	fn profile_level(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropProfileLevel_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: profile_level")
+	}
+	
+	/// NVVE_FORCE_INTRA,
+	fn force_intra(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropForceIntra_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: force_intra")
+	}
+	
+	/// NVVE_FORCE_IDR,
+	fn force_idr(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropForceIDR_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: force_idr")
+	}
+	
+	/// NVVE_CLEAR_STAT,
+	fn clear_stat(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropClearStat_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: clear_stat")
+	}
+	
+	/// NVVE_SET_DEINTERLACE,
+	fn di_mode(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropDIMode_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: di_mode")
+	}
+	
+	/// NVVE_PRESETS,
+	fn presets(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropPresets_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: presets")
+	}
+	
+	/// NVVE_DISABLE_CABAC,
+	fn disable_cabac(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropDisableCabac_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: disable_cabac")
+	}
+	
+	/// NVVE_CONFIGURE_NALU_FRAMING_TYPE
+	fn nalu_framing_type(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropNaluFramingType_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: nalu_framing_type")
+	}
+	
+	/// NVVE_DISABLE_SPS_PPS
+	fn disable_spspps(&self) -> i32 {
+		unsafe { sys::cv_cudacodec_EncoderParams_getPropDisableSPSPPS_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: disable_spspps")
+	}
+	
+	/// Saves parameters to config file.
+	/// 
+	/// ## Parameters
+	/// * configFile: Config file name.
+	fn save(&self, config_file: &str) -> Result<()> {
+		extern_container_arg!(config_file);
+		unsafe { sys::cv_cudacodec_EncoderParams_save_const_const_StringR(self.as_raw_EncoderParams(), config_file.opencv_as_extern()) }.into_result()
+	}
+	
+}
+
+pub trait EncoderParamsTrait: crate::cudacodec::EncoderParamsTraitConst {
+	fn as_raw_mut_EncoderParams(&mut self) -> *mut c_void;
+
+	/// NVVE_P_INTERVAL,
+	fn set_p_interval(&mut self, val: i32) -> () {
+		unsafe { sys::cv_cudacodec_EncoderParams_setPropP_Interval_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_p_interval")
+	}
+	
 	/// NVVE_IDR_PERIOD,
 	fn set_idr_period(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropIDR_Period_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_idr_period")
 	}
 	
-	/// NVVE_DYNAMIC_GOP,
-	fn dynamic_gop(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropDynamicGOP_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: dynamic_gop")
-	}
-	
 	/// NVVE_DYNAMIC_GOP,
 	fn set_dynamic_gop(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropDynamicGOP_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_dynamic_gop")
 	}
 	
-	/// NVVE_RC_TYPE,
-	fn rc_type(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropRCType_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: rc_type")
-	}
-	
 	/// NVVE_RC_TYPE,
 	fn set_rc_type(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropRCType_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_rc_type")
 	}
 	
-	/// NVVE_AVG_BITRATE,
-	fn avg_bitrate(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropAvgBitrate_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: avg_bitrate")
-	}
-	
 	/// NVVE_AVG_BITRATE,
 	fn set_avg_bitrate(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropAvgBitrate_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_avg_bitrate")
 	}
 	
-	/// NVVE_PEAK_BITRATE,
-	fn peak_bitrate(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropPeakBitrate_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: peak_bitrate")
-	}
-	
 	/// NVVE_PEAK_BITRATE,
 	fn set_peak_bitrate(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropPeakBitrate_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_peak_bitrate")
 	}
 	
-	/// NVVE_QP_LEVEL_INTRA,
-	fn qp_level_intra(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropQP_Level_Intra_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: qp_level_intra")
-	}
-	
 	/// NVVE_QP_LEVEL_INTRA,
 	fn set_qp_level_intra(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropQP_Level_Intra_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_qp_level_intra")
 	}
 	
-	/// NVVE_QP_LEVEL_INTER_P,
-	fn qp_level_inter_p(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropQP_Level_InterP_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: qp_level_inter_p")
-	}
-	
 	/// NVVE_QP_LEVEL_INTER_P,
 	fn set_qp_level_inter_p(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropQP_Level_InterP_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_qp_level_inter_p")
 	}
 	
-	/// NVVE_QP_LEVEL_INTER_B,
-	fn qp_level_inter_b(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropQP_Level_InterB_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: qp_level_inter_b")
-	}
-	
 	/// NVVE_QP_LEVEL_INTER_B,
 	fn set_qp_level_inter_b(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropQP_Level_InterB_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_qp_level_inter_b")
 	}
 	
-	/// NVVE_DEBLOCK_MODE,
-	fn deblock_mode(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropDeblockMode_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: deblock_mode")
-	}
-	
 	/// NVVE_DEBLOCK_MODE,
 	fn set_deblock_mode(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropDeblockMode_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_deblock_mode")
 	}
 	
-	/// NVVE_PROFILE_LEVEL,
-	fn profile_level(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropProfileLevel_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: profile_level")
-	}
-	
 	/// NVVE_PROFILE_LEVEL,
 	fn set_profile_level(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropProfileLevel_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_profile_level")
 	}
 	
-	/// NVVE_FORCE_INTRA,
-	fn force_intra(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropForceIntra_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: force_intra")
-	}
-	
 	/// NVVE_FORCE_INTRA,
 	fn set_force_intra(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropForceIntra_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_force_intra")
 	}
 	
-	/// NVVE_FORCE_IDR,
-	fn force_idr(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropForceIDR_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: force_idr")
-	}
-	
 	/// NVVE_FORCE_IDR,
 	fn set_force_idr(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropForceIDR_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_force_idr")
 	}
 	
-	/// NVVE_CLEAR_STAT,
-	fn clear_stat(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropClearStat_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: clear_stat")
-	}
-	
 	/// NVVE_CLEAR_STAT,
 	fn set_clear_stat(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropClearStat_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_clear_stat")
 	}
 	
-	/// NVVE_SET_DEINTERLACE,
-	fn di_mode(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropDIMode_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: di_mode")
-	}
-	
 	/// NVVE_SET_DEINTERLACE,
 	fn set_di_mode(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropDIMode_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_di_mode")
 	}
 	
-	/// NVVE_PRESETS,
-	fn presets(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropPresets_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: presets")
-	}
-	
 	/// NVVE_PRESETS,
 	fn set_presets(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropPresets_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_presets")
 	}
 	
-	/// NVVE_DISABLE_CABAC,
-	fn disable_cabac(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropDisableCabac_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: disable_cabac")
-	}
-	
 	/// NVVE_DISABLE_CABAC,
 	fn set_disable_cabac(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropDisableCabac_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_disable_cabac")
 	}
 	
-	/// NVVE_CONFIGURE_NALU_FRAMING_TYPE
-	fn nalu_framing_type(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropNaluFramingType_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: nalu_framing_type")
-	}
-	
 	/// NVVE_CONFIGURE_NALU_FRAMING_TYPE
 	fn set_nalu_framing_type(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropNaluFramingType_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_nalu_framing_type")
 	}
 	
-	/// NVVE_DISABLE_SPS_PPS
-	fn disable_spspps(&self) -> i32 {
-		unsafe { sys::cv_cudacodec_EncoderParams_getPropDisableSPSPPS_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: disable_spspps")
-	}
-	
 	/// NVVE_DISABLE_SPS_PPS
 	fn set_disable_spspps(&mut self, val: i32) -> () {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropDisableSPSPPS_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_disable_spspps")
@@ -492,15 +509,6 @@ pub trait EncoderParamsTrait {
 		unsafe { sys::cv_cudacodec_EncoderParams_load_const_StringR(self.as_raw_mut_EncoderParams(), config_file.opencv_as_extern()) }.into_result()
 	}
 	
-	/// Saves parameters to config file.
-	/// 
-	/// ## Parameters
-	/// * configFile: Config file name.
-	fn save(&self, config_file: &str) -> Result<()> {
-		extern_container_arg!(config_file);
-		unsafe { sys::cv_cudacodec_EncoderParams_save_const_const_StringR(self.as_raw_EncoderParams(), config_file.opencv_as_extern()) }.into_result()
-	}
-	
 }
 
 /// Different parameters for CUDA video encoder.
@@ -517,15 +525,13 @@ impl Drop for EncoderParams {
 	}
 }
 
-impl EncoderParams {
-	#[inline] pub fn as_raw_EncoderParams(&self) -> *const c_void { self.as_raw() }
-	#[inline] pub fn as_raw_mut_EncoderParams(&mut self) -> *mut c_void { self.as_raw_mut() }
-}
-
 unsafe impl Send for EncoderParams {}
 
-impl crate::cudacodec::EncoderParamsTrait for EncoderParams {
+impl crate::cudacodec::EncoderParamsTraitConst for EncoderParams {
 	#[inline] fn as_raw_EncoderParams(&self) -> *const c_void { self.as_raw() }
+}
+
+impl crate::cudacodec::EncoderParamsTrait for EncoderParams {
 	#[inline] fn as_raw_mut_EncoderParams(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
@@ -566,8 +572,17 @@ impl FormatInfo {
 /// Interface for video demultiplexing. :
 /// 
 /// User can implement own demultiplexing by implementing this interface.
-pub trait RawVideoSource {
+pub trait RawVideoSourceConst {
 	fn as_raw_RawVideoSource(&self) -> *const c_void;
+
+	/// Returns information about video file format.
+	fn format(&self) -> Result<crate::cudacodec::FormatInfo> {
+		unsafe { sys::cv_cudacodec_RawVideoSource_format_const(self.as_raw_RawVideoSource()) }.into_result()
+	}
+	
+}
+
+pub trait RawVideoSource: crate::cudacodec::RawVideoSourceConst {
 	fn as_raw_mut_RawVideoSource(&mut self) -> *mut c_void;
 
 	/// Returns next packet with RAW video frame.
@@ -579,11 +594,6 @@ pub trait RawVideoSource {
 		unsafe { sys::cv_cudacodec_RawVideoSource_getNextPacket_unsigned_charXX_size_tX(self.as_raw_mut_RawVideoSource(), data as *mut  _ as *mut  *mut  _, size) }.into_result()
 	}
 	
-	/// Returns information about video file format.
-	fn format(&self) -> Result<crate::cudacodec::FormatInfo> {
-		unsafe { sys::cv_cudacodec_RawVideoSource_format_const(self.as_raw_RawVideoSource()) }.into_result()
-	}
-	
 }
 
 /// Video reader interface.
@@ -592,8 +602,17 @@ pub trait RawVideoSource {
 /// Note:
 ///    *   An example on how to use the videoReader class can be found at
 ///        opencv_source_code/samples/gpu/video_reader.cpp
-pub trait VideoReader {
+pub trait VideoReaderConst {
 	fn as_raw_VideoReader(&self) -> *const c_void;
+
+	/// Returns information about video file format.
+	fn format(&self) -> Result<crate::cudacodec::FormatInfo> {
+		unsafe { sys::cv_cudacodec_VideoReader_format_const(self.as_raw_VideoReader()) }.into_result()
+	}
+	
+}
+
+pub trait VideoReader: crate::cudacodec::VideoReaderConst {
 	fn as_raw_mut_VideoReader(&mut self) -> *mut c_void;
 
 	/// Grabs, decodes and returns the next video frame.
@@ -607,11 +626,6 @@ pub trait VideoReader {
 		unsafe { sys::cv_cudacodec_VideoReader_nextFrame_GpuMatR_StreamR(self.as_raw_mut_VideoReader(), frame.as_raw_mut_GpuMat(), stream.as_raw_mut_Stream()) }.into_result()
 	}
 	
-	/// Returns information about video file format.
-	fn format(&self) -> Result<crate::cudacodec::FormatInfo> {
-		unsafe { sys::cv_cudacodec_VideoReader_format_const(self.as_raw_VideoReader()) }.into_result()
-	}
-	
 }
 
 /// Video writer interface.
@@ -625,8 +639,16 @@ pub trait VideoReader {
 /// Note:
 ///    *   An example on how to use the videoWriter class can be found at
 ///        opencv_source_code/samples/gpu/video_writer.cpp
-pub trait VideoWriter {
+pub trait VideoWriterConst {
 	fn as_raw_VideoWriter(&self) -> *const c_void;
+
+	fn get_encoder_params(&self) -> Result<crate::cudacodec::EncoderParams> {
+		unsafe { sys::cv_cudacodec_VideoWriter_getEncoderParams_const(self.as_raw_VideoWriter()) }.into_result().map(|r| unsafe { crate::cudacodec::EncoderParams::opencv_from_extern(r) } )
+	}
+	
+}
+
+pub trait VideoWriter: crate::cudacodec::VideoWriterConst {
 	fn as_raw_mut_VideoWriter(&mut self) -> *mut c_void;
 
 	/// Writes the next video frame.
@@ -645,8 +667,4 @@ pub trait VideoWriter {
 		unsafe { sys::cv_cudacodec_VideoWriter_write_const__InputArrayR_bool(self.as_raw_mut_VideoWriter(), frame.as_raw__InputArray(), last_frame) }.into_result()
 	}
 	
-	fn get_encoder_params(&self) -> Result<crate::cudacodec::EncoderParams> {
-		unsafe { sys::cv_cudacodec_VideoWriter_getEncoderParams_const(self.as_raw_VideoWriter()) }.into_result().map(|r| unsafe { crate::cudacodec::EncoderParams::opencv_from_extern(r) } )
-	}
-	
 }
