@@ -19,7 +19,7 @@
 //! means cmake should find it using `find_package(HDF5)` .
 use crate::{mod_prelude::*, core, sys, types};
 pub mod prelude {
-	pub use { super::HDF5 };
+	pub use { super::HDF5Const, super::HDF5 };
 }
 
 /// Get the chunk sizes of a dataset. see also: dsgetsize()
@@ -78,7 +78,7 @@ pub const HDF5_H5_UNLIMITED: i32 = -1;
 /// }
 /// ```
 /// 
-pub fn open(hdf5_filename: &str) -> Result<core::Ptr::<dyn crate::hdf::HDF5>> {
+pub fn open(hdf5_filename: &str) -> Result<core::Ptr<dyn crate::hdf::HDF5>> {
 	extern_container_arg!(hdf5_filename);
 	unsafe { sys::cv_hdf_open_const_StringR(hdf5_filename.opencv_as_extern()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::hdf::HDF5>::opencv_from_extern(r) } )
 }
@@ -86,42 +86,9 @@ pub fn open(hdf5_filename: &str) -> Result<core::Ptr::<dyn crate::hdf::HDF5>> {
 /// Hierarchical Data Format version 5 interface.
 /// 
 /// Notice that this module is compiled only when hdf5 is correctly installed.
-pub trait HDF5 {
+pub trait HDF5Const {
 	fn as_raw_HDF5(&self) -> *const c_void;
-	fn as_raw_mut_HDF5(&mut self) -> *mut c_void;
 
-	/// Close and release hdf5 object.
-	fn close(&mut self) -> Result<()> {
-		unsafe { sys::cv_hdf_HDF5_close(self.as_raw_mut_HDF5()) }.into_result()
-	}
-	
-	/// Create a group.
-	/// ## Parameters
-	/// * grlabel: specify the hdf5 group label.
-	/// 
-	/// Create a hdf5 group with default properties. The group is closed automatically after creation.
-	/// 
-	/// 
-	/// Note: Groups are useful for better organising multiple datasets. It is possible to create subgroups within any group.
-	/// Existence of a particular group can be checked using hlexists(). In case of subgroups, a label would be e.g: 'Group1/SubGroup1'
-	/// where SubGroup1 is within the root group Group1. Before creating a subgroup, its parent group MUST be created.
-	/// 
-	/// - In this example, Group1 will have one subgroup called SubGroup1:
-	/// 
-	///  [create_group](https://github.com/opencv/opencv_contrib/blob/4.5.3/modules/hdf/samples/create_groups.cpp#L1)
-	/// 
-	///  The corresponding result visualized using the HDFView tool is
-	/// 
-	///  ![Visualization of groups using the HDFView tool](https://docs.opencv.org/4.5.3/create_groups.png)
-	/// 
-	/// 
-	/// Note: When a dataset is created with dscreate() or kpcreate(), it can be created within a group by specifying the
-	/// full path within the label. In our example, it would be: 'Group1/SubGroup1/MyDataSet'. It is not thread safe.
-	fn grcreate(&mut self, grlabel: &str) -> Result<()> {
-		extern_container_arg!(grlabel);
-		unsafe { sys::cv_hdf_HDF5_grcreate_const_StringR(self.as_raw_mut_HDF5(), grlabel.opencv_as_extern()) }.into_result()
-	}
-	
 	/// Check if label exists or not.
 	/// ## Parameters
 	/// * label: specify the hdf5 dataset label.
@@ -148,175 +115,6 @@ pub trait HDF5 {
 		unsafe { sys::cv_hdf_HDF5_atexists_const_const_StringR(self.as_raw_HDF5(), atlabel.opencv_as_extern()) }.into_result()
 	}
 	
-	/// Delete an attribute from the root group.
-	/// 
-	/// ## Parameters
-	/// * atlabel: the attribute to be deleted.
-	/// 
-	/// 
-	/// Note: CV_Error() is called if the given attribute does not exist. Use atexists()
-	/// to check whether it exists or not beforehand.
-	/// ## See also
-	/// atexists, atwrite, atread
-	fn atdelete(&mut self, atlabel: &str) -> Result<()> {
-		extern_container_arg!(atlabel);
-		unsafe { sys::cv_hdf_HDF5_atdelete_const_StringR(self.as_raw_mut_HDF5(), atlabel.opencv_as_extern()) }.into_result()
-	}
-	
-	/// Write an attribute inside the root group.
-	/// 
-	/// ## Parameters
-	/// * value: attribute value.
-	/// * atlabel: attribute name.
-	/// 
-	/// The following example demonstrates how to write an attribute of type cv::String:
-	/// 
-	///  [snippets_write_str](https://github.com/opencv/opencv_contrib/blob/4.5.3/modules/hdf/samples/read_write_attributes.cpp#L1)
-	/// 
-	/// 
-	/// Note: CV_Error() is called if the given attribute already exists. Use atexists()
-	/// to check whether it exists or not beforehand. And use atdelete() to delete
-	/// it if it already exists.
-	/// ## See also
-	/// atexists, atdelete, atread
-	fn atwrite(&mut self, value: i32, atlabel: &str) -> Result<()> {
-		extern_container_arg!(atlabel);
-		unsafe { sys::cv_hdf_HDF5_atwrite_const_int_const_StringR(self.as_raw_mut_HDF5(), value, atlabel.opencv_as_extern()) }.into_result()
-	}
-	
-	/// Read an attribute from the root group.
-	/// 
-	/// ## Parameters
-	/// * value: address where the attribute is read into
-	/// * atlabel: attribute name
-	/// 
-	/// The following example demonstrates how to read an attribute of type cv::String:
-	/// 
-	///  [snippets_read_str](https://github.com/opencv/opencv_contrib/blob/4.5.3/modules/hdf/samples/read_write_attributes.cpp#L1)
-	/// 
-	/// 
-	/// Note: The attribute MUST exist, otherwise CV_Error() is called. Use atexists()
-	/// to check if it exists beforehand.
-	/// ## See also
-	/// atexists, atdelete, atwrite
-	fn atread(&mut self, value: &mut i32, atlabel: &str) -> Result<()> {
-		extern_container_arg!(atlabel);
-		unsafe { sys::cv_hdf_HDF5_atread_intX_const_StringR(self.as_raw_mut_HDF5(), value, atlabel.opencv_as_extern()) }.into_result()
-	}
-	
-	/// Write an attribute into the root group.
-	/// 
-	/// ## Parameters
-	/// * value: attribute value. Currently, only n-d continuous multi-channel arrays are supported.
-	/// * atlabel: attribute name.
-	/// 
-	/// 
-	/// Note: CV_Error() is called if the given attribute already exists. Use atexists()
-	/// to check whether it exists or not beforehand. And use atdelete() to delete
-	/// it if it already exists.
-	/// ## See also
-	/// atexists, atdelete, atread.
-	/// 
-	/// ## Overloaded parameters
-	fn atwrite_1(&mut self, value: f64, atlabel: &str) -> Result<()> {
-		extern_container_arg!(atlabel);
-		unsafe { sys::cv_hdf_HDF5_atwrite_const_double_const_StringR(self.as_raw_mut_HDF5(), value, atlabel.opencv_as_extern()) }.into_result()
-	}
-	
-	/// Read an attribute from the root group.
-	/// 
-	/// ## Parameters
-	/// * value: attribute value. Currently, only n-d continuous multi-channel arrays are supported.
-	/// * atlabel: attribute name.
-	/// 
-	/// 
-	/// Note: The attribute MUST exist, otherwise CV_Error() is called. Use atexists()
-	/// to check if it exists beforehand.
-	/// ## See also
-	/// atexists, atdelete, atwrite
-	/// 
-	/// ## Overloaded parameters
-	fn atread_1(&mut self, value: &mut f64, atlabel: &str) -> Result<()> {
-		extern_container_arg!(atlabel);
-		unsafe { sys::cv_hdf_HDF5_atread_doubleX_const_StringR(self.as_raw_mut_HDF5(), value, atlabel.opencv_as_extern()) }.into_result()
-	}
-	
-	/// Write an attribute into the root group.
-	/// 
-	/// ## Parameters
-	/// * value: attribute value. Currently, only n-d continuous multi-channel arrays are supported.
-	/// * atlabel: attribute name.
-	/// 
-	/// 
-	/// Note: CV_Error() is called if the given attribute already exists. Use atexists()
-	/// to check whether it exists or not beforehand. And use atdelete() to delete
-	/// it if it already exists.
-	/// ## See also
-	/// atexists, atdelete, atread.
-	/// 
-	/// ## Overloaded parameters
-	fn atwrite_2(&mut self, value: &str, atlabel: &str) -> Result<()> {
-		extern_container_arg!(value);
-		extern_container_arg!(atlabel);
-		unsafe { sys::cv_hdf_HDF5_atwrite_const_StringR_const_StringR(self.as_raw_mut_HDF5(), value.opencv_as_extern(), atlabel.opencv_as_extern()) }.into_result()
-	}
-	
-	/// Read an attribute from the root group.
-	/// 
-	/// ## Parameters
-	/// * value: attribute value. Currently, only n-d continuous multi-channel arrays are supported.
-	/// * atlabel: attribute name.
-	/// 
-	/// 
-	/// Note: The attribute MUST exist, otherwise CV_Error() is called. Use atexists()
-	/// to check if it exists beforehand.
-	/// ## See also
-	/// atexists, atdelete, atwrite
-	/// 
-	/// ## Overloaded parameters
-	fn atread_2(&mut self, value: &mut String, atlabel: &str) -> Result<()> {
-		string_arg_output_send!(via value_via);
-		extern_container_arg!(atlabel);
-		let out = unsafe { sys::cv_hdf_HDF5_atread_StringX_const_StringR(self.as_raw_mut_HDF5(), &mut value_via, atlabel.opencv_as_extern()) }.into_result();
-		string_arg_output_receive!(out, value_via => value);
-		out
-	}
-	
-	/// Write an attribute into the root group.
-	/// 
-	/// ## Parameters
-	/// * value: attribute value. Currently, only n-d continuous multi-channel arrays are supported.
-	/// * atlabel: attribute name.
-	/// 
-	/// 
-	/// Note: CV_Error() is called if the given attribute already exists. Use atexists()
-	/// to check whether it exists or not beforehand. And use atdelete() to delete
-	/// it if it already exists.
-	/// ## See also
-	/// atexists, atdelete, atread.
-	fn atwrite_3(&mut self, value: &dyn core::ToInputArray, atlabel: &str) -> Result<()> {
-		input_array_arg!(value);
-		extern_container_arg!(atlabel);
-		unsafe { sys::cv_hdf_HDF5_atwrite_const__InputArrayR_const_StringR(self.as_raw_mut_HDF5(), value.as_raw__InputArray(), atlabel.opencv_as_extern()) }.into_result()
-	}
-	
-	/// Read an attribute from the root group.
-	/// 
-	/// ## Parameters
-	/// * value: attribute value. Currently, only n-d continuous multi-channel arrays are supported.
-	/// * atlabel: attribute name.
-	/// 
-	/// 
-	/// Note: The attribute MUST exist, otherwise CV_Error() is called. Use atexists()
-	/// to check if it exists beforehand.
-	/// ## See also
-	/// atexists, atdelete, atwrite
-	fn atread_3(&mut self, value: &mut dyn core::ToOutputArray, atlabel: &str) -> Result<()> {
-		output_array_arg!(value);
-		extern_container_arg!(atlabel);
-		unsafe { sys::cv_hdf_HDF5_atread_const__OutputArrayR_const_StringR(self.as_raw_mut_HDF5(), value.as_raw__OutputArray(), atlabel.opencv_as_extern()) }.into_result()
-	}
-	
 	/// Create and allocate storage for n-dimensional dataset, single or multichannel type.
 	/// ## Parameters
 	/// * n_dims: declare number of dimensions
@@ -564,7 +362,7 @@ pub trait HDF5 {
 	/// 
 	/// 
 	/// ## Overloaded parameters
-	fn dscreate_2(&self, rows: i32, cols: i32, typ: i32, dslabel: &str, compresslevel: i32, dims_chunks: &core::Vector::<i32>) -> Result<()> {
+	fn dscreate_2(&self, rows: i32, cols: i32, typ: i32, dslabel: &str, compresslevel: i32, dims_chunks: &core::Vector<i32>) -> Result<()> {
 		extern_container_arg!(dslabel);
 		unsafe { sys::cv_hdf_HDF5_dscreate_const_const_int_const_int_const_int_const_StringR_const_int_const_vector_int_R(self.as_raw_HDF5(), rows, cols, typ, dslabel.opencv_as_extern(), compresslevel, dims_chunks.as_raw_VectorOfi32()) }.into_result()
 	}
@@ -661,7 +459,7 @@ pub trait HDF5 {
 	/// ## C++ default parameters
 	/// * compresslevel: HDF5::H5_NONE
 	/// * dims_chunks: vector<int>()
-	fn dscreate_6(&self, sizes: &core::Vector::<i32>, typ: i32, dslabel: &str, compresslevel: i32, dims_chunks: &core::Vector::<i32>) -> Result<()> {
+	fn dscreate_6(&self, sizes: &core::Vector<i32>, typ: i32, dslabel: &str, compresslevel: i32, dims_chunks: &core::Vector<i32>) -> Result<()> {
 		extern_container_arg!(dslabel);
 		unsafe { sys::cv_hdf_HDF5_dscreate_const_const_vector_int_R_const_int_const_StringR_const_int_const_vector_int_R(self.as_raw_HDF5(), sizes.as_raw_VectorOfi32(), typ, dslabel.opencv_as_extern(), compresslevel, dims_chunks.as_raw_VectorOfi32()) }.into_result()
 	}
@@ -767,7 +565,7 @@ pub trait HDF5 {
 	/// 
 	/// ## C++ default parameters
 	/// * dims_flag: HDF5::H5_GETDIMS
-	fn dsgetsize(&self, dslabel: &str, dims_flag: i32) -> Result<core::Vector::<i32>> {
+	fn dsgetsize(&self, dslabel: &str, dims_flag: i32) -> Result<core::Vector<i32>> {
 		extern_container_arg!(dslabel);
 		unsafe { sys::cv_hdf_HDF5_dsgetsize_const_const_StringR_int(self.as_raw_HDF5(), dslabel.opencv_as_extern(), dims_flag) }.into_result().map(|r| unsafe { core::Vector::<i32>::opencv_from_extern(r) } )
 	}
@@ -801,7 +599,7 @@ pub trait HDF5 {
 	
 	/// ## C++ default parameters
 	/// * dims_counts: vector<int>()
-	fn dswrite_2(&self, array: &dyn core::ToInputArray, dslabel: &str, dims_offset: &core::Vector::<i32>, dims_counts: &core::Vector::<i32>) -> Result<()> {
+	fn dswrite_2(&self, array: &dyn core::ToInputArray, dslabel: &str, dims_offset: &core::Vector<i32>, dims_counts: &core::Vector<i32>) -> Result<()> {
 		input_array_arg!(array);
 		extern_container_arg!(dslabel);
 		unsafe { sys::cv_hdf_HDF5_dswrite_const_const__InputArrayR_const_StringR_const_vector_int_R_const_vector_int_R(self.as_raw_HDF5(), array.as_raw__InputArray(), dslabel.opencv_as_extern(), dims_offset.as_raw_VectorOfi32(), dims_counts.as_raw_VectorOfi32()) }.into_result()
@@ -892,7 +690,7 @@ pub trait HDF5 {
 	
 	/// ## C++ default parameters
 	/// * dims_counts: vector<int>()
-	fn dsinsert_2(&self, array: &dyn core::ToInputArray, dslabel: &str, dims_offset: &core::Vector::<i32>, dims_counts: &core::Vector::<i32>) -> Result<()> {
+	fn dsinsert_2(&self, array: &dyn core::ToInputArray, dslabel: &str, dims_offset: &core::Vector<i32>, dims_counts: &core::Vector<i32>) -> Result<()> {
 		input_array_arg!(array);
 		extern_container_arg!(dslabel);
 		unsafe { sys::cv_hdf_HDF5_dsinsert_const_const__InputArrayR_const_StringR_const_vector_int_R_const_vector_int_R(self.as_raw_HDF5(), array.as_raw__InputArray(), dslabel.opencv_as_extern(), dims_offset.as_raw_VectorOfi32(), dims_counts.as_raw_VectorOfi32()) }.into_result()
@@ -967,7 +765,7 @@ pub trait HDF5 {
 	
 	/// ## C++ default parameters
 	/// * dims_counts: vector<int>()
-	fn dsread_2(&self, array: &mut dyn core::ToOutputArray, dslabel: &str, dims_offset: &core::Vector::<i32>, dims_counts: &core::Vector::<i32>) -> Result<()> {
+	fn dsread_2(&self, array: &mut dyn core::ToOutputArray, dslabel: &str, dims_offset: &core::Vector<i32>, dims_counts: &core::Vector<i32>) -> Result<()> {
 		output_array_arg!(array);
 		extern_container_arg!(dslabel);
 		unsafe { sys::cv_hdf_HDF5_dsread_const_const__OutputArrayR_const_StringR_const_vector_int_R_const_vector_int_R(self.as_raw_HDF5(), array.as_raw__OutputArray(), dslabel.opencv_as_extern(), dims_offset.as_raw_VectorOfi32(), dims_counts.as_raw_VectorOfi32()) }.into_result()
@@ -1148,7 +946,7 @@ pub trait HDF5 {
 	/// ## C++ default parameters
 	/// * offset: H5_NONE
 	/// * counts: H5_NONE
-	fn kpwrite(&self, keypoints: core::Vector::<core::KeyPoint>, kplabel: &str, offset: i32, counts: i32) -> Result<()> {
+	fn kpwrite(&self, keypoints: core::Vector<core::KeyPoint>, kplabel: &str, offset: i32, counts: i32) -> Result<()> {
 		extern_container_arg!(kplabel);
 		unsafe { sys::cv_hdf_HDF5_kpwrite_const_const_vector_KeyPoint__const_StringR_const_int_const_int(self.as_raw_HDF5(), keypoints.as_raw_VectorOfKeyPoint(), kplabel.opencv_as_extern(), offset, counts) }.into_result()
 	}
@@ -1191,7 +989,7 @@ pub trait HDF5 {
 	/// ## C++ default parameters
 	/// * offset: H5_NONE
 	/// * counts: H5_NONE
-	fn kpinsert(&self, keypoints: core::Vector::<core::KeyPoint>, kplabel: &str, offset: i32, counts: i32) -> Result<()> {
+	fn kpinsert(&self, keypoints: core::Vector<core::KeyPoint>, kplabel: &str, offset: i32, counts: i32) -> Result<()> {
 		extern_container_arg!(kplabel);
 		unsafe { sys::cv_hdf_HDF5_kpinsert_const_const_vector_KeyPoint__const_StringR_const_int_const_int(self.as_raw_HDF5(), keypoints.as_raw_VectorOfKeyPoint(), kplabel.opencv_as_extern(), offset, counts) }.into_result()
 	}
@@ -1238,9 +1036,215 @@ pub trait HDF5 {
 	/// ## C++ default parameters
 	/// * offset: H5_NONE
 	/// * counts: H5_NONE
-	fn kpread(&self, keypoints: &mut core::Vector::<core::KeyPoint>, kplabel: &str, offset: i32, counts: i32) -> Result<()> {
+	fn kpread(&self, keypoints: &mut core::Vector<core::KeyPoint>, kplabel: &str, offset: i32, counts: i32) -> Result<()> {
 		extern_container_arg!(kplabel);
 		unsafe { sys::cv_hdf_HDF5_kpread_const_vector_KeyPoint_R_const_StringR_const_int_const_int(self.as_raw_HDF5(), keypoints.as_raw_mut_VectorOfKeyPoint(), kplabel.opencv_as_extern(), offset, counts) }.into_result()
 	}
 	
 }
+
+pub trait HDF5: crate::hdf::HDF5Const {
+	fn as_raw_mut_HDF5(&mut self) -> *mut c_void;
+
+	/// Close and release hdf5 object.
+	fn close(&mut self) -> Result<()> {
+		unsafe { sys::cv_hdf_HDF5_close(self.as_raw_mut_HDF5()) }.into_result()
+	}
+	
+	/// Create a group.
+	/// ## Parameters
+	/// * grlabel: specify the hdf5 group label.
+	/// 
+	/// Create a hdf5 group with default properties. The group is closed automatically after creation.
+	/// 
+	/// 
+	/// Note: Groups are useful for better organising multiple datasets. It is possible to create subgroups within any group.
+	/// Existence of a particular group can be checked using hlexists(). In case of subgroups, a label would be e.g: 'Group1/SubGroup1'
+	/// where SubGroup1 is within the root group Group1. Before creating a subgroup, its parent group MUST be created.
+	/// 
+	/// - In this example, Group1 will have one subgroup called SubGroup1:
+	/// 
+	///  [create_group](https://github.com/opencv/opencv_contrib/blob/4.5.3/modules/hdf/samples/create_groups.cpp#L1)
+	/// 
+	///  The corresponding result visualized using the HDFView tool is
+	/// 
+	///  ![Visualization of groups using the HDFView tool](https://docs.opencv.org/4.5.3/create_groups.png)
+	/// 
+	/// 
+	/// Note: When a dataset is created with dscreate() or kpcreate(), it can be created within a group by specifying the
+	/// full path within the label. In our example, it would be: 'Group1/SubGroup1/MyDataSet'. It is not thread safe.
+	fn grcreate(&mut self, grlabel: &str) -> Result<()> {
+		extern_container_arg!(grlabel);
+		unsafe { sys::cv_hdf_HDF5_grcreate_const_StringR(self.as_raw_mut_HDF5(), grlabel.opencv_as_extern()) }.into_result()
+	}
+	
+	/// Delete an attribute from the root group.
+	/// 
+	/// ## Parameters
+	/// * atlabel: the attribute to be deleted.
+	/// 
+	/// 
+	/// Note: CV_Error() is called if the given attribute does not exist. Use atexists()
+	/// to check whether it exists or not beforehand.
+	/// ## See also
+	/// atexists, atwrite, atread
+	fn atdelete(&mut self, atlabel: &str) -> Result<()> {
+		extern_container_arg!(atlabel);
+		unsafe { sys::cv_hdf_HDF5_atdelete_const_StringR(self.as_raw_mut_HDF5(), atlabel.opencv_as_extern()) }.into_result()
+	}
+	
+	/// Write an attribute inside the root group.
+	/// 
+	/// ## Parameters
+	/// * value: attribute value.
+	/// * atlabel: attribute name.
+	/// 
+	/// The following example demonstrates how to write an attribute of type cv::String:
+	/// 
+	///  [snippets_write_str](https://github.com/opencv/opencv_contrib/blob/4.5.3/modules/hdf/samples/read_write_attributes.cpp#L1)
+	/// 
+	/// 
+	/// Note: CV_Error() is called if the given attribute already exists. Use atexists()
+	/// to check whether it exists or not beforehand. And use atdelete() to delete
+	/// it if it already exists.
+	/// ## See also
+	/// atexists, atdelete, atread
+	fn atwrite(&mut self, value: i32, atlabel: &str) -> Result<()> {
+		extern_container_arg!(atlabel);
+		unsafe { sys::cv_hdf_HDF5_atwrite_const_int_const_StringR(self.as_raw_mut_HDF5(), value, atlabel.opencv_as_extern()) }.into_result()
+	}
+	
+	/// Read an attribute from the root group.
+	/// 
+	/// ## Parameters
+	/// * value: address where the attribute is read into
+	/// * atlabel: attribute name
+	/// 
+	/// The following example demonstrates how to read an attribute of type cv::String:
+	/// 
+	///  [snippets_read_str](https://github.com/opencv/opencv_contrib/blob/4.5.3/modules/hdf/samples/read_write_attributes.cpp#L1)
+	/// 
+	/// 
+	/// Note: The attribute MUST exist, otherwise CV_Error() is called. Use atexists()
+	/// to check if it exists beforehand.
+	/// ## See also
+	/// atexists, atdelete, atwrite
+	fn atread(&mut self, value: &mut i32, atlabel: &str) -> Result<()> {
+		extern_container_arg!(atlabel);
+		unsafe { sys::cv_hdf_HDF5_atread_intX_const_StringR(self.as_raw_mut_HDF5(), value, atlabel.opencv_as_extern()) }.into_result()
+	}
+	
+	/// Write an attribute into the root group.
+	/// 
+	/// ## Parameters
+	/// * value: attribute value. Currently, only n-d continuous multi-channel arrays are supported.
+	/// * atlabel: attribute name.
+	/// 
+	/// 
+	/// Note: CV_Error() is called if the given attribute already exists. Use atexists()
+	/// to check whether it exists or not beforehand. And use atdelete() to delete
+	/// it if it already exists.
+	/// ## See also
+	/// atexists, atdelete, atread.
+	/// 
+	/// ## Overloaded parameters
+	fn atwrite_1(&mut self, value: f64, atlabel: &str) -> Result<()> {
+		extern_container_arg!(atlabel);
+		unsafe { sys::cv_hdf_HDF5_atwrite_const_double_const_StringR(self.as_raw_mut_HDF5(), value, atlabel.opencv_as_extern()) }.into_result()
+	}
+	
+	/// Read an attribute from the root group.
+	/// 
+	/// ## Parameters
+	/// * value: attribute value. Currently, only n-d continuous multi-channel arrays are supported.
+	/// * atlabel: attribute name.
+	/// 
+	/// 
+	/// Note: The attribute MUST exist, otherwise CV_Error() is called. Use atexists()
+	/// to check if it exists beforehand.
+	/// ## See also
+	/// atexists, atdelete, atwrite
+	/// 
+	/// ## Overloaded parameters
+	fn atread_1(&mut self, value: &mut f64, atlabel: &str) -> Result<()> {
+		extern_container_arg!(atlabel);
+		unsafe { sys::cv_hdf_HDF5_atread_doubleX_const_StringR(self.as_raw_mut_HDF5(), value, atlabel.opencv_as_extern()) }.into_result()
+	}
+	
+	/// Write an attribute into the root group.
+	/// 
+	/// ## Parameters
+	/// * value: attribute value. Currently, only n-d continuous multi-channel arrays are supported.
+	/// * atlabel: attribute name.
+	/// 
+	/// 
+	/// Note: CV_Error() is called if the given attribute already exists. Use atexists()
+	/// to check whether it exists or not beforehand. And use atdelete() to delete
+	/// it if it already exists.
+	/// ## See also
+	/// atexists, atdelete, atread.
+	/// 
+	/// ## Overloaded parameters
+	fn atwrite_2(&mut self, value: &str, atlabel: &str) -> Result<()> {
+		extern_container_arg!(value);
+		extern_container_arg!(atlabel);
+		unsafe { sys::cv_hdf_HDF5_atwrite_const_StringR_const_StringR(self.as_raw_mut_HDF5(), value.opencv_as_extern(), atlabel.opencv_as_extern()) }.into_result()
+	}
+	
+	/// Read an attribute from the root group.
+	/// 
+	/// ## Parameters
+	/// * value: attribute value. Currently, only n-d continuous multi-channel arrays are supported.
+	/// * atlabel: attribute name.
+	/// 
+	/// 
+	/// Note: The attribute MUST exist, otherwise CV_Error() is called. Use atexists()
+	/// to check if it exists beforehand.
+	/// ## See also
+	/// atexists, atdelete, atwrite
+	/// 
+	/// ## Overloaded parameters
+	fn atread_2(&mut self, value: &mut String, atlabel: &str) -> Result<()> {
+		string_arg_output_send!(via value_via);
+		extern_container_arg!(atlabel);
+		let out = unsafe { sys::cv_hdf_HDF5_atread_StringX_const_StringR(self.as_raw_mut_HDF5(), &mut value_via, atlabel.opencv_as_extern()) }.into_result();
+		string_arg_output_receive!(out, value_via => value);
+		out
+	}
+	
+	/// Write an attribute into the root group.
+	/// 
+	/// ## Parameters
+	/// * value: attribute value. Currently, only n-d continuous multi-channel arrays are supported.
+	/// * atlabel: attribute name.
+	/// 
+	/// 
+	/// Note: CV_Error() is called if the given attribute already exists. Use atexists()
+	/// to check whether it exists or not beforehand. And use atdelete() to delete
+	/// it if it already exists.
+	/// ## See also
+	/// atexists, atdelete, atread.
+	fn atwrite_3(&mut self, value: &dyn core::ToInputArray, atlabel: &str) -> Result<()> {
+		input_array_arg!(value);
+		extern_container_arg!(atlabel);
+		unsafe { sys::cv_hdf_HDF5_atwrite_const__InputArrayR_const_StringR(self.as_raw_mut_HDF5(), value.as_raw__InputArray(), atlabel.opencv_as_extern()) }.into_result()
+	}
+	
+	/// Read an attribute from the root group.
+	/// 
+	/// ## Parameters
+	/// * value: attribute value. Currently, only n-d continuous multi-channel arrays are supported.
+	/// * atlabel: attribute name.
+	/// 
+	/// 
+	/// Note: The attribute MUST exist, otherwise CV_Error() is called. Use atexists()
+	/// to check if it exists beforehand.
+	/// ## See also
+	/// atexists, atdelete, atwrite
+	fn atread_3(&mut self, value: &mut dyn core::ToOutputArray, atlabel: &str) -> Result<()> {
+		output_array_arg!(value);
+		extern_container_arg!(atlabel);
+		unsafe { sys::cv_hdf_HDF5_atread_const__OutputArrayR_const_StringR(self.as_raw_mut_HDF5(), value.as_raw__OutputArray(), atlabel.opencv_as_extern()) }.into_result()
+	}
+	
+}
